# OctaDist  Copyright (C) 2019  Rangsiman Ketkaew et al.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
# ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

import tkinter as tk
from tkinter import scrolledtext as tkscrolled

from scipy.spatial import distance

from octadist.src import linear, util


class DataComplex:
    """
    Show info of input complex.

    Parameters
    ----------
    master : object, optional
        If None, use tk.Tk().
        If not None, use tk.Toplevel(master).

    icon : str, optional
        If None, use tkinter default icon.
        If not None, use user-defined icon.

    Examples
    --------
    >>> file = "File_1"
    >>> atom = ['Fe', 'N', 'N', 'N', 'O', 'O', 'O']
    >>> coord = [[2.298354000, 5.161785000, 7.971898000],
                 [1.885657000, 4.804777000, 6.183726000],
                 [1.747515000, 6.960963000, 7.932784000],
                 [4.094380000, 5.807257000, 7.588689000],
                 [0.539005000, 4.482809000, 8.460004000],
                 [2.812425000, 3.266553000, 8.131637000],
                 [2.886404000, 5.392925000, 9.848966000]]
    >>> my_app = DataComplex()
    >>> my_app.add_name(file)
    >>> my_app.add_coord(atom, coord)

    """
    def __init__(self, master=None, icon=None):
        if master is None:
            self.wd = tk.Tk()
        else:
            self.wd = tk.Toplevel(master)

        self.icon = icon

        self.start_app()

    def start_app(self):
        """
        Start application.

        """
        if self.icon is not None:
            self.wd.wm_iconbitmap(self.icon)
        self.wd.title("Complex info")
        self.wd.geometry("550x500")
        self.wd.option_add("*Font", "Arial 10")
        self.wd.resizable(0, 0)

        self.frame = tk.Frame(self.wd)
        self.frame.grid()
        self.box = tkscrolled.ScrolledText(self.frame, wrap="word", undo="True",
                                           width="75", height="30")
        self.box.grid(row=0, pady="5", padx="5")

    def add_name(self, file_name):
        """
        Add file name to box.

        Parameters
        ----------
        file_name : array_like
            List containing the names of all input files.

        """
        self.box.insert(tk.END, f"File: {file_name.split('/')[-1]}\n")

    def add_coord(self, atom, coord):
        """
        Add atomic symbols and coordinates to box.

        Parameters
        ----------
        atom : array_like
            Atomic labels of full complex.
        coord : array_like
            Atomic coordinates of full complex.

        """
        self.box.insert(tk.END, "===============================\n")
        self.box.insert(tk.END, f"{len(atom)}\n")
        atoms = list(set(atom))
        self.box.insert(tk.END, f"List of atoms: {atoms}\n")

        for i in range(len(coord)):
            self.box.insert(tk.END, f"{atom[i]:>2}\t"
                                    f"{coord[i][0]:9.6f}\t\t"
                                    f"{coord[i][1]:9.6f}\t\t"
                                    f"{coord[i][2]:9.6f}")
            self.box.insert(tk.END, "\n")
        self.box.insert(tk.END, "\n\n")


class StructParam:
    """
    Show structural parameters of structure.

    Parameters
    ----------
    master : object, optional
        If None, use tk.Tk().
        If not None, use tk.Toplevel(master).

    icon : str, optional
        If None, use tkinter default icon.
        If not None, use user-defined icon.

    Examples
    --------
    >>> metal = 'Fe'
    >>> atom = ['Fe', 'N', 'N', 'N', 'O', 'O', 'O']
    >>> coord = [[2.298354000, 5.161785000, 7.971898000],
                 [1.885657000, 4.804777000, 6.183726000],
                 [1.747515000, 6.960963000, 7.932784000],
                 [4.094380000, 5.807257000, 7.588689000],
                 [0.539005000, 4.482809000, 8.460004000],
                 [2.812425000, 3.266553000, 8.131637000],
                 [2.886404000, 5.392925000, 9.848966000]]
    >>> my_app = StructParam()
    >>> my_app.add_metal(metal)
    >>> my_app.add_coord(atom, coord)

    """
    def __init__(self, master=None, icon=None):
        if master is None:
            self.wd = tk.Tk()
        else:
            self.wd = tk.Toplevel(master)

        self.icon = icon

        self.start_app()

    def start_app(self):
        """
        Start application.

        """
        if self.icon is not None:
            self.wd.wm_iconbitmap(self.icon)
        self.wd.title("Results")
        self.wd.geometry("380x530")
        self.wd.option_add("*Font", "Arial 10")
        self.wd.resizable(0, 0)
        
        self.frame = tk.Frame(self.wd)
        self.frame.grid()
        self.lbl = tk.Label(self.frame, text="Structural parameters")
        self.lbl.grid(row=0, pady="5", padx="5", sticky=tk.W)
        self.box = tkscrolled.ScrolledText(self.frame, wrap="word", undo="True",
                                           width="50", height="30")
        self.box.grid(row=1, pady="5", padx="5")
        
    def add_number(self, number):
        """
        Add file number to box.
        
        Parameters
        ----------
        number : int
            File number.
            
        """
        self.box.insert(tk.INSERT, f"Number : {number}\n")
        
    def add_metal(self, metal):
        """
        Add metal atom to box:
        
        Parameters
        ----------
        metal : str
            Metal atom.
        
        """
        self.box.insert(tk.END, f"Metal: {metal}\n")

    def add_coord(self, atom, coord):
        """
        Add atomic symbols and coordinates to box.

        Parameters
        ----------
        atom : array_like
            Atomic labels of full complex.
        coord : array_like
            Atomic coordinates of full complex.

        """
        self.box.insert(tk.END, "Bond distance (Å)")

        # Bond distance
        for i in range(len(coord)):
            for j in range(i + 1, len(coord)):
                dist = distance.euclidean(coord[i], coord[j])

                if i == 0:
                    texts = f"{atom[i]}-{atom[j]}{j}\t\t{dist:10.6f}"
                else:
                    texts = f"{atom[i]}{i}-{atom[j]}{j}\t\t{dist:10.6f}"

                self.box.insert(tk.END, "\n" + texts)

        self.box.insert(tk.END, "\n\nBond angle (°)")

        # Bond angle.
        for i in range(len(coord)):
            for j in range(i + 1, len(coord)):
                for k in range(j + 1, 7):
                    vec1 = coord[i] - coord[j]
                    vec2 = coord[k] - coord[j]
                    angle = linear.angle_btw_vectors(vec1, vec2)

                    if i == 0:
                        texts = f"{atom[k]}{k}-{atom[i]}-{atom[j]}{j}\t\t{angle:10.6f}"
                    else:
                        texts = f"{atom[k]}{k}-{atom[i]}{i}-{atom[j]}{j}\t\t{angle:10.6f}"

                    self.box.insert(tk.END, "\n" + texts)

        self.box.insert(tk.END, "\n\n=================================\n\n")


class SurfaceArea:
    """
    Find the area of the faces of octahedral structure.

    Three ligand atoms are vertices of triangular face

    Parameters
    ----------
    master : object, optional
        If None, use tk.Tk().
        If not None, use tk.Toplevel(master).

    icon : str, optional
        If None, use tkinter default icon.
        If not None, use user-defined icon.

    Examples
    --------
    >>> metal = 'Fe'
    >>> coord = [[2.298354000, 5.161785000, 7.971898000],
                 [1.885657000, 4.804777000, 6.183726000],
                 [1.747515000, 6.960963000, 7.932784000],
                 [4.094380000, 5.807257000, 7.588689000],
                 [0.539005000, 4.482809000, 8.460004000],
                 [2.812425000, 3.266553000, 8.131637000],
                 [2.886404000, 5.392925000, 9.848966000]]
    >>> my_app = SurfaceArea()
    >>> my_app.add_metal(metal)
    >>> my_app.add_octa(coord)

    """
    def __init__(self, master=None, icon=None):
        if master is None:
            self.wd = tk.Tk()
        else:
            self.wd = tk.Toplevel(master)

        self.icon = icon

        self.start_app()

    def start_app(self):
        """
        Start application.

        """
        if self.icon is not None:
            self.wd.wm_iconbitmap(self.icon)
        self.wd.title("The area of triangular face")
        self.wd.geometry("380x500")
        self.wd.option_add("*Font", "Arial 10")
        self.wd.resizable(0, 0)

        self.frame = tk.Frame(self.wd)
        self.frame.grid()
        self.box = tkscrolled.ScrolledText(self.frame, wrap="word", undo="True",
                                           width="50", height="30")
        self.box.grid(row=0, pady="5", padx="5")

    def add_number(self, number):
        """
        Add file number to box.

        Parameters
        ----------
        number : int
            File number.

        """
        self.box.insert(tk.INSERT, f"Number : {number}\n")

    def add_metal(self, metal):
        """
        Add metal atom to box:

        Parameters
        ----------
        metal : str
            Metal atom.

        """
        self.box.insert(tk.END, f"Metal: {metal}\n")

    def add_octa(self, coord):
        """
        Add atomic coordinates of octahedron and find triangle area of the faces.

        Parameters
        ----------
        coord : array_like
            Atomic coordinates of octahedral structure.

        See Also
        --------
        octadist.src.util.find_faces_octa

        """
        a_ref, c_ref, a_oppo, c_oppo = util.find_faces_octa(coord)

        self.box.insert(tk.END, "\t\tAtoms*\t\tArea (Å³)\n")

        total_area = 0
        for i in range(8):
            area = linear.triangle_area(c_ref[i][0], c_ref[i][1], c_ref[i][2])
            self.box.insert(tk.END, f"Face no. {i + 1}:\t\t{a_ref[i]}\t\t{area:10.6f}\n")
            total_area += area

        self.box.insert(tk.END, f"\nThe total surface area:   {total_area:10.6f}\n")

        self.box.insert(tk.END, "\n==============================\n\n")



# OctaDist  Copyright (C) 2019  Rangsiman Ketkaew et al.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
# ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

import numpy as np


def project_atom_onto_line(p, a, b):
    """
    Find the point projection on the line, which defined by two distinct end points.

    | a <----> b
    |
    | P(x) = x1 + (p - x1).(x2 - x1)/(x2-x1).(x2-x1) * (x2-x1)

    Parameters
    ----------
    p : array_like
        Coordinate of point to project.
    a : array_like
        Coordinate of head atom of the line.
    b : array_like
        Coordinate of tail atom of the line.

    Returns
    -------
    projected_point : ndarray
        The projected point on the orthogonal line.

    Examples
    --------
    >>> # point to project
    >>> p = [10.1873, 5.7463, 5.615]
    >>> # head and end points of line
    >>> a = [8.494, 5.9735, 4.8091]
    >>> b = [9.6526, 6.4229, 7.3079]
    >>> project_atom_onto_line(p, a, b)
    [9.07023235 6.19701012 6.05188388]

    """
    p = np.asarray(p, dtype=np.float64)
    a = np.asarray(a, dtype=np.float64)
    b = np.asarray(b, dtype=np.float64)

    ap = p - a
    ab = b - a

    projected_point = a + (np.dot(ap, ab) / np.dot(ab, ab)) * ab

    return projected_point


def project_atom_onto_plane(p, a, b, c, d):
    """
    Find the orthogonal vector of point onto the given plane.
    The equation of plane is Ax + By + Cz = D and point is (L, M, N),
    then the location on the plane that is closest to the point (P, Q, R) is

    | (P, Q, R) = (L, M, N) + λ * (A, B, C)
    |
    | where λ = (D - ( A*L + B*M + C*N)) / (A^2 + B^2 + C^2).

    Parameters
    ----------
    p : array_like
        Point to project.
    a : int or float
        Coefficient of the equation of the plane.
    b : int or float
        Coefficient of the equation of the plane.
    c : int or float
        Coefficient of the equation of the plane.
    d : int or float
        Coefficient of the equation of the plane.

    Returns
    -------
    projected_point: ndarray
        The projected point on the orthogonal plane.

    Examples
    --------
    >>> # point to project
    >>> p = [10.1873, 5.7463, 5.615]
    >>> # coefficient of the equation of the plane
    >>> a = -3.231203733528
    >>> b = -0.9688526458499996
    >>> c = 0.9391692927779998
    >>> d = -4.940497273569501
    >>> project_atom_onto_plane(p, a, b, c, d)
    [2.73723598 3.51245316 7.78040705]

    """
    p = np.asarray(p, dtype=np.float64)
    plane = np.array([a, b, c], dtype=np.float64)

    lambda_plane = (d - (a * p[0] + b * p[1] + c * p[2])) / np.dot(plane, plane)

    projected_point = p + lambda_plane * plane

    return projected_point



# OctaDist  Copyright (C) 2019  Rangsiman Ketkaew et al.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
# ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

import numpy as np
from scipy.spatial import distance

from octadist.src import plane, projection


def find_bonds(atom, coord, cutoff_global=2.0, cutoff_hydrogen=1.2):
    """
    Find all bond distance and filter the possible bonds.

    - Compute distance of all bonds
    - Screen bonds out based on global cutoff distance
    - Screen H bonds out based on local cutoff distance

    Parameters
    ----------
    atom : list
        List of atomic labels of molecule.
    coord : list
        List of atomic coordinates of molecule.
    cutoff_global : int or float
        Global cutoff for screening bonds.
        Default value is 2.0.
    cutoff_hydrogen : int or float
        Cutoff for screening hydrogen bonds.
        Default value is 1.2.

    Returns
    -------
    filtered_bond_2 : list
        Selected bonds in molecule after screening.

    Examples
    --------
    >>> atom = ['Fe', 'N', 'N', 'N', 'O', 'O', 'O']
    >>> coord = [[2.298354000, 5.161785000, 7.971898000],
                 [1.885657000, 4.804777000, 6.183726000],
                 [1.747515000, 6.960963000, 7.932784000],
                 [4.094380000, 5.807257000, 7.588689000],
                 [0.539005000, 4.482809000, 8.460004000],
                 [2.812425000, 3.266553000, 8.131637000],
                 [2.886404000, 5.392925000, 9.848966000]]
    >>> pair_bond, bond_dist = find_bonds(atom, coord)
    >>> pair_bond
    [['Fe', 'N'],
     ['Fe', 'N'],
     ['Fe', 'N'],
     ['Fe', 'O'],
     ['Fe', 'O'],
     ['Fe', 'O']]
    >>> bond_dist
    [[[2.298354, 5.161785, 7.971898], [1.885657, 4.804777, 6.183726]],
     [[2.298354, 5.161785, 7.971898], [1.747515, 6.960963, 7.932784]],
     [[2.298354, 5.161785, 7.971898], [4.094380, 5.807257, 7.588689]],
     [[2.298354, 5.161785, 7.971898], [0.539005, 4.482809, 8.460004]],
     [[2.298354, 5.161785, 7.971898], [2.812425, 3.266553, 8.131637]],
     [[2.298354, 5.161785, 7.971898], [2.886404, 5.392925, 9.848966]]]

    """
    all_pair = []
    all_bond = []

    for i in range(len(coord)):
        for j in range(i + 1, len(coord)):
            if i == 0:
                dist = distance.euclidean(coord[i], coord[j])
            else:
                dist = distance.euclidean(coord[i], coord[j])

            all_pair.append([atom[i], atom[j]])
            all_bond.append([coord[i], coord[j], dist])

    filtered_pair_1 = []
    filtered_bond_1 = []

    for i in range(len(all_bond)):
        if all_bond[i][2] <= cutoff_global:
            filtered_pair_1.append([all_pair[i][0],
                                    all_pair[i][1]])

            filtered_bond_1.append([all_bond[i][0],
                                    all_bond[i][1],
                                    all_bond[i][2]])

    filtered_pair_2 = []
    filtered_bond_2 = []

    for i in range(len(filtered_bond_1)):
        if filtered_pair_1[i][0] == "H" or filtered_pair_1[i][1] == "H":
            if filtered_bond_1[i][2] <= cutoff_hydrogen:
                filtered_pair_2.append([filtered_pair_1[i][0], filtered_pair_1[i][1]])
                filtered_bond_2.append([filtered_bond_1[i][0], filtered_bond_1[i][1]])
        else:
            filtered_pair_2.append([filtered_pair_1[i][0], filtered_pair_1[i][1]])
            filtered_bond_2.append([filtered_bond_1[i][0], filtered_bond_1[i][1]])

    return filtered_pair_2, filtered_bond_2


def find_faces_octa(c_octa):
    """
    Find the eight faces of octahedral structure.

    1. Choose 3 atoms out of 6 ligand atoms.
        The total number of combination is 20.
    2. Orthogonally project metal center atom onto the face:
        m ----> m'
    3. Calculate the shortest distance between original metal center to its projected point.
    4. Sort the 20 faces in ascending order of the shortest distance.
    5. Delete 12 faces that closest to metal center atom (first 12 faces).
    6. The remaining 8 faces are the (reference) face of octahedral structure.
    7. Find 8 opposite faces.

    | Reference plane             Opposite plane
    |    [[1 2 3]                    [[4 5 6]
    |     [1 2 4]        --->         [3 5 6]
    |       ...                         ...
    |     [2 3 5]]                    [1 4 6]]

    Parameters
    ----------
    c_octa : array_like
        Atomic coordinates of octahedral structure.

    Returns
    -------
    a_ref_f : list
        Atomic labels of reference face.
    c_ref_f : ndarray
        Atomic coordinates of reference face.
    a_oppo_f : list
        Atomic labels of opposite face.
    c_oppo_f : ndarray
        Atomic coordinates of opposite face.

    See Also
    --------
    octadist.src.plane.find_eq_of_plane :
        Find the equation of the plane.
    octadist.src.projection.project_atom_onto_plane :
        Orthogonal projection of point onto the plane.

    Examples
    --------
    >>> coord = [[14.68572 18.49228  6.66716]
                 [14.86476 16.48821  7.43379]
                 [14.44181 20.594    6.21555]
                 [13.37473 17.23453  5.45099]
                 [16.26114 18.54903  8.20527]
                 [13.04897 19.25464  7.93122]
                 [16.09157 18.9617   5.02956]]
    >>> a_ref, c_ref, a_oppo, c_oppo = find_faces_octa(coord)
    >>> a_ref
    [[1, 3, 6], [1, 4, 6], [2, 3, 6], [2, 3, 5],
     [2, 4, 5], [1, 4, 5], [1, 3, 5], [2, 4, 6]]
    >>> c_ref
    [[[14.86476 16.48821  7.43379]
      [13.37473 17.23453  5.45099]
      [16.09157 18.9617   5.02956]],
     ...,
     ...,
     [[14.44181 20.594    6.21555]
      [16.26114 18.54903  8.20527]
      [16.09157 18.9617   5.02956]]]
    >>> a_octa
    [[2, 4, 5], [2, 3, 5], [1, 4, 5], [1, 4, 6],
     [1, 3, 6], [2, 3, 6], [2, 4, 6], [1, 3, 5]]
    >>> c_octa
    [[[14.44181 20.594    6.21555]
      [16.26114 18.54903  8.20527]
      [13.04897 19.25464  7.93122]],
     ...,
     ...,
     [[14.86476 16.48821  7.43379]
      [13.37473 17.23453  5.45099]
      [13.04897 19.25464  7.93122]]]

    """
    ########################
    # Find reference faces #
    ########################

    c_octa = np.asarray(c_octa, dtype=np.float64)

    # Find the shortest distance from metal center to each triangle
    dist = []
    a_ref_f = []
    c_ref_f = []

    for i in range(1, 5):
        for j in range(i + 1, 6):
            for k in range(j + 1, 7):
                a, b, c, d = plane.find_eq_of_plane(c_octa[i],
                                                    c_octa[j],
                                                    c_octa[k])
                m = projection.project_atom_onto_plane(c_octa[0], a, b, c, d)
                d_btw = distance.euclidean(m, c_octa[0])
                dist.append(d_btw)

                a_ref_f.append([i, j, k])
                c_ref_f.append([c_octa[i],
                                c_octa[j],
                                c_octa[k]])

    # Sort faces by distance in ascending order
    dist_a_c = list(zip(dist, a_ref_f, c_ref_f))
    dist_a_c.sort()
    dist, a_ref_f, c_ref_f = list(zip(*dist_a_c))
    c_ref_f = np.asarray(c_ref_f, dtype=np.float64)

    # Remove first 12 triangles, the rest of triangles is 8 faces of octahedron
    a_ref_f = a_ref_f[12:]
    c_ref_f = c_ref_f[12:]

    #######################
    # Find opposite faces #
    #######################

    all_atom = [1, 2, 3, 4, 5, 6]
    a_oppo_f = []

    for i in range(len(a_ref_f)):
        new_a_ref_f = []
        for j in all_atom:
            if j not in (a_ref_f[i][0], a_ref_f[i][1], a_ref_f[i][2]):
                new_a_ref_f.append(j)
        a_oppo_f.append(new_a_ref_f)

    c_oppo_f = []

    for i in range(len(a_oppo_f)):
        coord_oppo = []
        for j in range(3):
            coord_oppo.append([c_octa[int(a_oppo_f[i][j])][0],
                               c_octa[int(a_oppo_f[i][j])][1],
                               c_octa[int(a_oppo_f[i][j])]][2])
        c_oppo_f.append(coord_oppo)

    a_ref_f = list(a_ref_f)
    c_ref_f = list(c_ref_f)

    c_ref_f = np.asarray(c_ref_f, dtype=np.float64)
    c_oppo_f = np.asarray(c_oppo_f, dtype=np.float64)

    return a_ref_f, c_ref_f, a_oppo_f, c_oppo_f




#!/usr/bin/env python

# OctaDist  Copyright (C) 2019  Rangsiman Ketkaew et al.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
# ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

# Metadata file for distribution of OctaDist software on PyPI
# https://packaging.python.org/guides/distributing-packages-using-setuptools/

import setuptools

__version__ = "2.6.1"

with open("README.md", "r", encoding="utf-8") as f:
    long_description = f.read()

description = "OctaDist: A tool for calculating distortion parameters in coordination complexes."

setuptools.setup(
    name="octadist",
    version=__version__,
    author="Rangsiman Ketkaew et al.",
    author_email="rangsiman1993@gmail.com",
    description=description,
    long_description=long_description,
    long_description_content_type="text/markdown",
    license="GNU General Public License v3 (GPLv3) on top the license of Python.",
    url="https://octadist.github.io",
    download_url="https://github.com/OctaDist/OctaDist/releases",
    project_urls={
        'Documentation': 'https://octadist.readthedocs.io/en/latest/',
        'Source': 'https://github.com/OctaDist/OctaDist',
        'Tracker': 'https://github.com/OctaDist/OctaDist/issues',
    },
    packages=setuptools.find_packages(),
    install_requires=[
        'numpy',
        'scipy',
        'matplotlib',
        'rmsd'
    ],
    classifiers=[
        "Environment :: Console",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
        "Operating System :: POSIX",
        "Operating System :: POSIX :: AIX",
        "Operating System :: POSIX :: BSD",
        "Operating System :: POSIX :: Linux",
        "Operating System :: POSIX :: SunOS/Solaris",
        "Intended Audience :: Science/Research",
        "Intended Audience :: Developers",
        "Intended Audience :: End Users/Desktop",
        "Intended Audience :: Other Audience",
        "Natural Language :: English",
        "Topic :: Scientific/Engineering :: Chemistry",
        "Topic :: Scientific/Engineering :: Mathematics",
        "Topic :: Scientific/Engineering :: Visualization",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Multimedia :: Graphics :: 3D Modeling",
    ],
    keywords=[
        'chemistry',
        'computational chemistry',
        'inorganic chemistry',
        'crystallography',
        'coordination complex',
        'spin-crossover',
        'octahedral distortion parameter',
        'structural analysis',
        'Molecular visualization'
    ],
    python_requires='>=3, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*, !=3.4.*',
    entry_points={
        'console_scripts': [
            'octadist=octadist.octadist_gui:run_gui',
            'octadist_gui=octadist.octadist_gui:run_gui',
            'octadist_cli=octadist.octadist_cli:run_cli'
        ]
    },
)
